@@ -15,10 +15,10 @@ const ELLIPSIS = Services.prefs.getComplexValue("intl.ellipsis",
 // under the "accessibility.*" branch.
 const PREFS_WHITELIST = [
   "accessibility.",
+  "browser.display.",
   "browser.fixup.",
   "browser.history_expire_",
   "browser.link.open_newwindow",
-  "browser.mousewheel.",
   "browser.places.",
   "browser.startup.homepage",
   "browser.tabs.",
@@ -27,19 +27,24 @@ const PREFS_WHITELIST = [
   "extensions.checkCompatibility",
   "extensions.lastAppVersion",
   "font.",
+  "general.autoScroll",
   "general.useragent.",
   "gfx.",
   "html5.",
-  "mozilla.widget.render-mode",
   "layers.",
   "javascript.",
   "keyword.",
   "layout.css.dpi",
+  "mousewheel.",
   "network.",
+  "permissions.default.image",
   "places.",
+  "plugin.",
+  "plugins.",
   "print.",
   "privacy.",
-  "security."
+  "security.",
+  "webgl."
 ];
 
 // The blacklist, unlike the whitelist, is a list of regular expressions.
@@ -207,7 +212,7 @@ function populateGraphicsSection() {
     pushInfoRow(trGraphics, "driverVersion", gfxInfo.adapterDriverVersion);
     pushInfoRow(trGraphics, "driverDate", gfxInfo.adapterDriverDate);
 
-//@line 274 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 288 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
 
     var webglrenderer;
     var webglenabled;
@@ -218,9 +223,9 @@ function populateGraphicsSection() {
       webglrenderer = false;
       webglenabled = false;
     }
-//@line 292 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 306 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
     var webglfeature = gfxInfo.FEATURE_WEBGL_OPENGL;
-//@line 294 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 308 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
     pushFeatureInfoRow(trGraphics, "webglRenderer", webglfeature, webglenabled, webglrenderer);
 
     appendChildren(graphics_tbody, trGraphics);
@@ -255,9 +260,9 @@ function populateGraphicsSection() {
   if (acceleratedWindows) {
     msg += " " + mgrType;
   } else {
-//@line 331 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 345 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
     var feature = gfxInfo.FEATURE_OPENGL_LAYERS;
-//@line 333 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 347 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
     var errMsg = errorMessageForFeature(feature);
     if (errMsg)
       msg += ". " + errMsg;
@@ -389,7 +394,7 @@ function createTextForElement(elem) {
   text = text.replace(/\n\n\n+/g, "\n\n");
 
   // Actual CR/LF pairs are needed for some Windows text editors.
-//@line 467 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 481 "/builds/slave/m-beta-osx64-xr/build/toolkit/content/aboutSupport.js"
 
   return text;
 }
