@@ -3,6 +3,7 @@
 "use strict";
 
 Components.utils.import("resource://gre/modules/AddonManager.jsm");
+Components.utils.import("resource://gre/modules/AddonRepository.jsm");
 Components.utils.import("resource://gre/modules/Services.jsm");
 
 const Cc = Components.classes;
@@ -89,17 +90,25 @@ var gChecking = {
       self._progress.max = aAddons.length;
       self._progress.mode = "determined";
 
-      aAddons.forEach(function(aAddon) {
-        // Ignore disabled themes
-        if (aAddon.type != "theme" || !aAddon.userDisabled) {
-          gAddons[aAddon.id] = {
-            addon: aAddon,
-            install: null,
-            wasActive: aAddon.isActive
-          }
-        }
+      // Ensure compatibility overrides are up to date before checking for
+      // individual addon updates.
+      let ids = [addon.id for each (addon in aAddons)];
+      AddonRepository.repopulateCache(ids, function() {
+        AddonManagerPrivate.updateAddonRepositoryData(function() {
 
-        aAddon.findUpdates(self, AddonManager.UPDATE_WHEN_NEW_APP_INSTALLED);
+          aAddons.forEach(function(aAddon) {
+            // Ignore disabled themes
+            if (aAddon.type != "theme" || !aAddon.userDisabled) {
+              gAddons[aAddon.id] = {
+                addon: aAddon,
+                install: null,
+                wasActive: aAddon.isActive
+              }
+            }
+
+            aAddon.findUpdates(self, AddonManager.UPDATE_WHEN_NEW_APP_INSTALLED);
+          });
+        });
       });
     });
   },
